@@ -47,6 +47,7 @@
 #include "cut-ui.h"
 #include "cut-unified-differ.h"
 #include "cut-verbose-level.h"
+#include "cut-logger.h"
 
 /* enumerations from "cut-public.h" */
 GType
@@ -200,6 +201,92 @@ cut_verbose_level_error_get_type (void)
   }
   return etype;
 }
+GType
+cut_log_level_flags_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { CUT_LOG_LEVEL_DEFAULT, "CUT_LOG_LEVEL_DEFAULT", "default" },
+      { CUT_LOG_LEVEL_NONE, "CUT_LOG_LEVEL_NONE", "none" },
+      { CUT_LOG_LEVEL_CRITICAL, "CUT_LOG_LEVEL_CRITICAL", "critical" },
+      { CUT_LOG_LEVEL_ERROR, "CUT_LOG_LEVEL_ERROR", "error" },
+      { CUT_LOG_LEVEL_WARNING, "CUT_LOG_LEVEL_WARNING", "warning" },
+      { CUT_LOG_LEVEL_MESSAGE, "CUT_LOG_LEVEL_MESSAGE", "message" },
+      { CUT_LOG_LEVEL_INFO, "CUT_LOG_LEVEL_INFO", "info" },
+      { CUT_LOG_LEVEL_DEBUG, "CUT_LOG_LEVEL_DEBUG", "debug" },
+      { CUT_LOG_LEVEL_TRACE, "CUT_LOG_LEVEL_TRACE", "trace" },
+      { CUT_LOG_LEVEL_STATISTICS, "CUT_LOG_LEVEL_STATISTICS", "statistics" },
+      { CUT_LOG_LEVEL_PROFILE, "CUT_LOG_LEVEL_PROFILE", "profile" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static ("CutLogLevelFlags", values);
+  }
+  return etype;
+}
+GType
+cut_log_item_flags_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GFlagsValue values[] = {
+      { CUT_LOG_ITEM_DEFAULT, "CUT_LOG_ITEM_DEFAULT", "default" },
+      { CUT_LOG_ITEM_NONE, "CUT_LOG_ITEM_NONE", "none" },
+      { CUT_LOG_ITEM_DOMAIN, "CUT_LOG_ITEM_DOMAIN", "domain" },
+      { CUT_LOG_ITEM_LEVEL, "CUT_LOG_ITEM_LEVEL", "level" },
+      { CUT_LOG_ITEM_LOCATION, "CUT_LOG_ITEM_LOCATION", "location" },
+      { CUT_LOG_ITEM_TIME, "CUT_LOG_ITEM_TIME", "time" },
+      { CUT_LOG_ITEM_NAME, "CUT_LOG_ITEM_NAME", "name" },
+      { CUT_LOG_ITEM_PID, "CUT_LOG_ITEM_PID", "pid" },
+      { 0, NULL, NULL }
+    };
+    etype = g_flags_register_static ("CutLogItemFlags", values);
+  }
+  return etype;
+}
+GType
+cut_log_colorize_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { CUT_LOG_COLORIZE_DEFAULT, "CUT_LOG_COLORIZE_DEFAULT", "default" },
+      { CUT_LOG_COLORIZE_NONE, "CUT_LOG_COLORIZE_NONE", "none" },
+      { CUT_LOG_COLORIZE_CONSOLE, "CUT_LOG_COLORIZE_CONSOLE", "console" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("CutLogColorize", values);
+  }
+  return etype;
+}
+GType
+cut_enum_error_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { CUT_ENUM_ERROR_NULL_NAME, "CUT_ENUM_ERROR_NULL_NAME", "null-name" },
+      { CUT_ENUM_ERROR_UNKNOWN_NAME, "CUT_ENUM_ERROR_UNKNOWN_NAME", "unknown-name" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("CutEnumError", values);
+  }
+  return etype;
+}
+GType
+cut_flags_error_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { CUT_FLAGS_ERROR_NULL_NAME, "CUT_FLAGS_ERROR_NULL_NAME", "null-name" },
+      { CUT_FLAGS_ERROR_UNKNOWN_NAMES, "CUT_FLAGS_ERROR_UNKNOWN_NAMES", "unknown-names" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("CutFlagsError", values);
+  }
+  return etype;
+}
 
 
 
