@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <string.h>
@@ -90,7 +90,7 @@ constructor (GType type, guint n_props, GObjectConstructParam *props)
         object = klass->constructor(type, n_props, props);
         the_builder = CUT_REPORT_FACTORY_BUILDER(object);
     } else {
-        object = g_object_ref(G_OBJECT(the_builder));
+        object = g_object_ref(the_builder);
     }
 
     return object;
@@ -115,7 +115,7 @@ cut_report_factory_builder_init (CutReportFactoryBuilder *builder)
                 cut_win32_build_factory_module_dir_name("report");
         dir = win32_report_factory_module_dir;
 #else
-        dir = REPORT_FACTORY_MODULEDIR;
+        dir = REPORT_FACTORY_MODULE_DIR;
 #endif
     }
 
