@@ -2,6 +2,9 @@ module RDVisitorUtil
   module_function
   def remove_newline(string)
     content = ""
+    if string.respond_to?(:force_encoding)
+      string = string.dup.force_encoding("UTF-8")
+    end
     lines = string.split(/\r?\n\s*/)
     lines.each_with_index do |line, i|
       line = line.chomp
